# is-cow-alive

`is-cow-alive` is simple module that checks if the url in the config file is available.

## History and goal

The project is born in a chat with Andrés and Diego while we were drafting the practical part of a minimum viable package of the cowlab meeting.

## Features

- Returns OK or KO depending on the response code of the url

## Links

* [Code repository](https://github.com/cowlab-lugo/iscowalive)
* [Documentation]()
* [Pypi]()
* [GitHub Issues](https://github.com/cowlab-lugo/iscowalive/issues)
